pub struct Setting {
pub brand: NullString,
pub software: NullString,
pub version: NullString,
pub data: SettingData,
}Expand description
Represents a setting file.
Fields
brand: NullStringName of the brand.
The value seems to depend on the kind of file:
| File | Value |
|---|---|
DEVSETTING.DAT | PIONEER DJ |
DJMMYSETTING.DAT | PioneerDJ |
MYSETTING.DAT | PIONEER |
MYSETTING2.DAT | PIONEER |
software: NullStringName of the software (“rekordbox”).
version: NullStringSome kind of version number.
data: SettingDataThe actual settings data.
Implementations
Sourceimpl Setting
impl Setting
Sourcepub fn default_devsetting() -> Self
pub fn default_devsetting() -> Self
Create a new object containing the default values of a DEVSETTING.DAT file.
Sourcepub fn default_djmmysetting() -> Self
pub fn default_djmmysetting() -> Self
Create a new object containing the default values of a DJMMYSETTING.DAT file.
Sourcepub fn default_mysetting() -> Self
pub fn default_mysetting() -> Self
Create a new object containing the default values of a MYSETTING.DAT file.
Sourcepub fn default_mysetting2() -> Self
pub fn default_mysetting2() -> Self
Create a new object containing the default values of a MYSETTING2.DAT file.